(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     40335,       1299]
NotebookOptionsPosition[     31274,       1008]
NotebookOutlinePosition[     36817,       1181]
CellTagsIndexPosition[     36532,       1167]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Quantum Fourier Transform", "Title",
 CellTags->"c:1"],

Cell["\<\
State Implementation of the QFT
QCWAVE Version\
\>", "Subtitle",
 CellChangeTimes->{{3.4891674411656313`*^9, 3.4891674475758133`*^9}, {
  3.489167706088952*^9, 3.48916770838842*^9}}],

Cell[TextData[{
 "Version: 26-July-2010--For ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 7.0-8.0"
}], "Abstract",
 CellChangeTimes->{{3.395090887981901*^9, 3.395090925377634*^9}, {
  3.489167453263467*^9, 3.489167474101137*^9}, {3.512218354372922*^9, 
  3.51221835576024*^9}}],

Cell[TextData[ButtonBox["Click here to get the palette: QDENSpalette.nb",
 BaseStyle->"Hyperlink",
 ButtonData:>{"QDENSpalette.nb", None}]], "Text"],

Cell[CellGroupData[{

Cell["\<\
Quantum Fourier Transform      To open double click on down arrow --------->>\
\>", "Section",
 CellChangeTimes->{{3.512218325413497*^9, 3.5122183501469393`*^9}},
 FontFamily->"Times",
 CellTags->"c:2"],

Cell[CellGroupData[{

Cell[" Quantum Fourier Transform using  state vectors", "Subsection",
 CellFrame->True,
 CellChangeTimes->{{3.489167715577352*^9, 3.4891677216262093`*^9}},
 FontFamily->"Times",
 CellTags->{"c:3", "b:2.0.0"}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{"[", "1", "]"}], " ", "Quantum", " ", "Computation", " ", 
        "and", " ", "Quantum", " ", "Information"}], ",", " ", 
       RowBox[{"Nielsen", " ", "and", " ", "Chuang"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"],
 "\nLast Version: 25-Nov-2005"
}], "Abstract",
 CellTags->"b:2.0.0"],

Cell["\<\
The Quantum Fourier Transform is equivalent to the Discrete Fourier Transform 
We present here a state based algorithm that performs the QFT.\
\>", "Text",
 CellChangeTimes->{{3.4891675275023937`*^9, 3.4891675628758163`*^9}},
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<QDENSITY`Qdensity`\>\"", "]"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"?", "QDENSITY`Qdensity`*"}]], "Input",
 FontFamily->"Courier New",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"figure", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<QDENSITY/drawings/QFT.png\>\"", ",", "\"\<PNG\>\""}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"figure", ",", 
   RowBox[{"ImageSize", "\[Rule]", "900"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
The quantum Fourier transform of a vector written in its binary \
representation has a very nice expression (we follow the notation of Ref [1]) \
:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 FormBox[GridBox[{
    {Cell[BoxData[
      FormBox[
       RowBox[{
        RowBox[{"QuantumFourierTransformV", "[", 
         RowBox[{
          SubscriptBox["j", "1"], ",", 
          SubscriptBox["j", "2"], ",", "..", ",", 
          SubscriptBox["j", "n"]}], "]"}], "=", " "}], TraditionalForm]]], 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"|", "0"}]}], "\[RightAngleBracket]"}], "+", 
                    SuperscriptBox["e", 
                    RowBox[{"\[ImaginaryI]2\[Pi]0", ".", 
                    SubscriptBox["j", "n"]}]]}], "|", "1"}], 
                   "\[RightAngleBracket]"}], " ", ")"}], "\[CircleTimes]", 
                 RowBox[{
                  RowBox[{"(", " ", 
                   RowBox[{"|", "0"}]}], "\[RightAngleBracket]"}]}], "+", 
                SuperscriptBox["e", 
                 RowBox[{
                  RowBox[{"\[ImaginaryI]2\[Pi]0", ".", 
                   SubscriptBox["j", 
                    RowBox[{"n", "-", "1"}]]}], 
                  SubscriptBox["j", "n"]}]]}], "|", "1"}], 
              "\[RightAngleBracket]"}], " ", ")"}], "..."}], "\[CircleTimes]", 
           RowBox[{
            RowBox[{"(", " ", 
             RowBox[{"|", "0"}]}], "\[RightAngleBracket]"}]}], "+", 
          SuperscriptBox["e", 
           RowBox[{
            RowBox[{
             RowBox[{"\[ImaginaryI]2\[Pi]0", ".", 
              SubscriptBox["j", "1"]}], ".."}], 
            SubscriptBox["j", "n"]}]]}], "|", "1"}], "\[RightAngleBracket]"}],
        ")"}], "\n", "\n", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"0.", 
          SubscriptBox["j", "m"]}], ".."}], 
        SubscriptBox["j", "L"]}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           SubscriptBox["j", "m"], "/", "2"}], "+", 
          RowBox[{
           SubscriptBox["j", 
            RowBox[{"m", "+", "1"}]], "/", 
           SuperscriptBox["2", "2"]}], " ", "+"}], " ", "..."}], "+", 
        RowBox[{
         SubscriptBox["j", "L"], "/", 
         SuperscriptBox["2", 
          RowBox[{"L", "-", "m", "+", "1"}]]}]}]}]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], 
  TraditionalForm]], "DefinitionBox",
 GridBoxOptions->{GridBoxSpacings->{"Columns" -> {
     Offset[0.27999999999999997`], {
      Offset[0.5599999999999999]}, 
     Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
     Offset[0.2], {
      Offset[0.16]}, 
     Offset[0.2]}, "RowsIndexed" -> {}}},
 CellTags->{"S5.1.1", "b:2.0.0"}],

Cell[TextData[{
 "\nThe binary representation of the base vectors is:",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     RowBox[{"|", 
      SubscriptBox["j", "1"]}],
     TraditionalForm], ",", 
    SubscriptBox["j", "2"]}], TraditionalForm]]],
 ", ..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "N"], TraditionalForm]]],
 "\[RightAngleBracket].  A general vector maybe decomposed as:"
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 " |\[Psi]\[RightAngleBracket] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Sum]", " "}], TraditionalForm]]],
 "[ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "k"], TraditionalForm]]],
 "  * KetV[ IntegerDigits[k,2,N]] , {k,1,2^N}]\nThe function \
IntegerDigits[k,2,N] returns the number k in base 2 with N figures, which is \
the binary representation of the vector k."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 "Let's ",
 StyleBox["start ",
  FontWeight->"Bold"],
 "by defining the operation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.", 
    SubscriptBox["j", "m"]}], TraditionalForm]]],
 " ... ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "L"], TraditionalForm]]],
 ", which enters in the exponents of the Fourier Transform, we call it, \
Zeroff:\nThe symbol  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.", 
    SubscriptBox["j", "m"]}], TraditionalForm]]],
 " ... ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "L"], TraditionalForm]]],
 " denotes the series:     ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "m"], TraditionalForm]]],
 " /  2  + ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", 
    RowBox[{"m", "+", "1"}]], TraditionalForm]]],
 "/ 4 +  ......+ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "L"], TraditionalForm]]],
 " / ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    RowBox[{"L", "-", "m", "+", "1"}]], TraditionalForm]]],
 "= Zeroff.\nThe notation used is that vac is the vector in binary notation \
that we are going to Fourier Transform and the array R  stores the indices m \
to j ."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zeroff", "[", 
   RowBox[{"vac_", ",", "R_"}], "]"}], ":=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"vac", "[", 
      RowBox[{"[", 
       RowBox[{"R", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], "]"}], "/", 
     RowBox[{"2", "^", "i"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "R", "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
Then the Quantum Fourier Transform can be readily written  using tensor \
products of Kets:  (and its inverse);  this corresponds to Eq. 5.4 in Ref.[1].\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"QuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"Zeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{"2", "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"\[CapitalOmega]", "/", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{"L", "/", "2"}], ")"}]}]}]}], ";", "\[CapitalOmega]"}]}], 
     "]"}]}], ";"}], "  "}]], "Input",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"IQuantumFourierTransformV", "[", "vac_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[CapitalOmega]", ",", "L"}], "}"}], ",", 
      RowBox[{
       RowBox[{"L", "=", 
        RowBox[{"Length", "[", "vac", "]"}]}], ";", 
       RowBox[{"\[CapitalOmega]", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Ket", "[", "0", "]"}], "+", 
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
             RowBox[{"Zeroff", "[", 
              RowBox[{"vac", ",", 
               RowBox[{"Range", "[", 
                RowBox[{"L", ",", "L"}], "]"}]}], "]"}]}], "]"}], "*", 
           RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "2"}], ",", 
         RowBox[{"i", "\[LessEqual]", "L"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{
          RowBox[{"phass", "=", 
           RowBox[{
            RowBox[{"-", "2"}], "*", "\[Pi]", "*", " ", "\[ImaginaryI]", "*", 
            RowBox[{"Zeroff", "[", 
             RowBox[{"vac", ",", 
              RowBox[{"Range", "[", 
               RowBox[{
                RowBox[{"L", "-", "i", "+", "1"}], ",", "L"}], "]"}]}], 
             "]"}]}]}], ";", 
          RowBox[{"\[CapitalOmega]", "=", 
           RowBox[{"\[CapitalOmega]", "\[CircleTimes]", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Ket", "[", "0", "]"}], "+", 
              RowBox[{
               RowBox[{"Exp", "[", "phass", "]"}], "*", 
               RowBox[{"Ket", "[", "1", "]"}]}]}], ")"}]}]}]}]}], "]"}], ";", 
       RowBox[{"\[CapitalOmega]", "/", 
        RowBox[{"2", "^", 
         RowBox[{"(", 
          RowBox[{"L", "/", "2"}], ")"}]}]}]}]}], "]"}]}], ";"}], 
  "  "}]], "Input",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 "For example, let us compute the QFT of state vector  | 0,1,1 \
\[RightAngleBracket]  ( In the full computational base, this vector would \
correspond to  the matrix (00010000) that is since binary 011 is decimal 3,\n\
the matrix representing the state has a 1 in location four.\n NOTE that \
|0,0,1\[RightAngleBracket]+|1,0,0\[RightAngleBracket] \[NotEqual] |1,0,1\
\[RightAngleBracket] !!  ) \n Now consider the QFT of the state state vector  \
| 0,1,1 \[RightAngleBracket]  which is of length ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "3"], TraditionalForm]]]
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"QFT011", "=", 
  RowBox[{"QuantumFourierTransformV", "[", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}], "]"}]}]], "Input",
 CellTags->"b:2.0.0"],

Cell[TextData[{
 "As can be seen the output is a list of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", "N"], TraditionalForm]]],
 " numbers, where N is the dimension of our vector in the binary \
representation."
}], "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell["We can check whether it is normalized:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"Norm", "[", "QFT011", "]"}]], "Input",
 CellTags->"b:2.0.0"],

Cell[CellGroupData[{

Cell[TextData[{
 "A ",
 StyleBox["more general random vector (with N=4)",
  FontWeight->"Bold"],
 " could be:"
}], "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:4", "b:2.0.0"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RanVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"RandomReal", "[", 
      RowBox[{"{", 
       RowBox[{"0", ",", "2"}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "4"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"RanVector", "=", 
  FractionBox["RanVector", 
   RowBox[{"Norm", "[", "RanVector", "]"}]]}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"RanVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[
 RowBox[{"QFTVec", "=", 
  RowBox[{"Sum", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"RanVector", "[", 
      RowBox[{"[", 
       RowBox[{"i", "+", "1"}], "]"}], "]"}], 
     RowBox[{"QuantumFourierTransformV", "[", 
      RowBox[{"IntegerDigits", "[", 
       RowBox[{"i", ",", "2", ",", "4"}], "]"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", 
      RowBox[{
       RowBox[{"2", "^", "4"}], "-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
An we can then use the inverse and compare with the original vector:\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{"IQFTVec", "=", 
  RowBox[{"Chop", "[", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"QFTVec", "[", 
        RowBox[{"[", 
         RowBox[{"i", "+", "1"}], "]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "*", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "4"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{
        RowBox[{"2", "^", "4"}], "-", "1"}]}], "}"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"IQFTVec", "=", 
   RowBox[{"Flatten", "[", "IQFTVec", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Chop", "[", 
  RowBox[{"RanVector", "-", "IQFTVec"}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
The  inverse of the QFT and  the original vector prove to be the same, which \
is a check on the procedures.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of the Sin[x]/x function", "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:5", "b:2.0.0"}],

Cell["\<\
In this example, we construct our vector out of a known function, Sin[x/a]/x. \
We make use of 6 qubits. \
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SinVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"Sin", "[", 
       FractionBox[
        RowBox[{"i", " ", "4", " ", "\[Pi]"}], 
        SuperscriptBox["2", "6"]], "]"}], "i"], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "6"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SinVector", "=", 
   FractionBox["SinVector", 
    RowBox[{"Norm", "[", "SinVector", "]"}]]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"SinVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Sin[Number]\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTSin", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{"SinVector", "\[LeftDoubleBracket]", 
       RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
      RowBox[{"QuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Chop", "[", "QFTSin", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTSinplotRe", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Re", "[", 
     RowBox[{"N", "[", "QFTSin", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTSinplotIM", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Im", "[", "QFTSin", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTSinplotRe", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Real part of QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.05`"}], ",", "0.1`"}], "}"}]}]}], "]"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTSinplotIM", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Imaginary part QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.2`"}], ",", "0.2`"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["And we invert it to recover the original function:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IQFTSin", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{
       RowBox[{"QFTSin", "\[LeftDoubleBracket]", 
        RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"IQFTSin", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"N", "[", "IQFTSin", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "IQFTSin", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
The Quantum Fourier Transform is in fact the same as the Discrete Fourier \
Transform (DFT):; therefore, 
we can check our results by performing the DFT that is already provided in \
Mathematica.  For instance,  this last 
step of inverting is invoked by the command  InverseFourier[ ].
[NOTE: Although mathematically the same thing, it is essential to emphasize \
that the physical implementation of the QFT making good use of quantum \
interference is what makes it appealing.]\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"itras", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"InverseFourier", "[", "QFTSin", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"Flatten", "[", "itras", "]"}], "]"}]}], "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of a constant function", "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:6", "b:2.0.0"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"CteVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "6"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CteVector", "=", 
   FractionBox["CteVector", 
    RowBox[{"Norm", "[", "CteVector", "]"}]]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"CteVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Cte\>\""}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTCte", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{"CteVector", "\[LeftDoubleBracket]", 
       RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
      RowBox[{"QuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Chop", "[", "QFTCte", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTCteplotRe", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Re", "[", 
     RowBox[{"N", "[", "QFTCte", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTCteplotIM", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Im", "[", "QFTCte", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTCteplotRe", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Real part of QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.05`"}], ",", "0.1`"}], "}"}]}]}], "]"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTCteplotIM", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Imaginary part QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.2`"}], ",", "0.2`"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["And we invert it to recover the original function:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IQFTCte", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{
       RowBox[{"QFTCte", "\[LeftDoubleBracket]", 
        RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"IQFTCte", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"N", "[", "IQFTCte", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "IQFTCte", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],

Cell[CellGroupData[{

Cell["QFT of the Mod[x,5] function", "Subsubsection",
 FontFamily->"Helvetica",
 CellTags->{"c:7", "b:2.0.0"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ModVector", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{"i", ",", "5"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       SuperscriptBox["2", "6"]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ModVector", "=", 
   FractionBox["ModVector", 
    RowBox[{"Norm", "[", "ModVector", "]"}]]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{"ModVector", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Mod[Number,5]\>\""}], "}"}]}]}], 
  "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
we apply the quantum Fourier transform: (NOTE we compute the QFT of the base \
vectors)\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"QFTMod", "=", 
   RowBox[{"N", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{"ModVector", "\[LeftDoubleBracket]", 
       RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], " ", 
      RowBox[{"QuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"Chop", "[", "QFTMod", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTModplotRe", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Re", "[", 
     RowBox[{"N", "[", "QFTMod", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"QFTModplotIM", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Im", "[", "QFTMod", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTModplotRe", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Real part of QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.05`"}], ",", "0.1`"}], "}"}]}]}], "]"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "QFTModplotIM", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Number", ",", "\"\<Imaginary part QFT\>\""}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.2`"}], ",", "0.2`"}], "}"}]}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["And we invert it to recover the original function:", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"IQFTMod", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "0"}], 
      RowBox[{
       SuperscriptBox["2", "6"], "-", "1"}]], 
     RowBox[{
      RowBox[{
       RowBox[{"QFTMod", "\[LeftDoubleBracket]", 
        RowBox[{"i", "+", "1"}], "\[RightDoubleBracket]"}], 
       "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], " ", 
      RowBox[{"IQuantumFourierTransformV", "[", 
       RowBox[{"IntegerDigits", "[", 
        RowBox[{"i", ",", "2", ",", "6"}], "]"}], "]"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"IQFTMod", "=", 
   RowBox[{"Chop", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"N", "[", "IQFTMod", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", "IQFTMod", "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellTags->"b:2.0.0"],

Cell["\<\
This kind of periodicity plays an important role in Shor's algorithm.\
\>", "Text",
 FontFamily->"Helvetica",
 CellTags->"b:2.0.0"],

Cell[BoxData["Quit"], "Input",
 CellTags->"b:2.0.1"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"References", ":"}], 
      RowBox[{
       RowBox[{
        RowBox[{"[", "1", "]"}], " ", "Quantum", " ", "Computation", " ", 
        "and", " ", "Quantum", " ", "Information"}], ",", " ", 
       RowBox[{"Nielsen", " ", "and", " ", "Chuang"}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]], 
  "DefinitionBox",
  GridBoxOptions->{
  GridBoxDividers->{
   "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
    "RowsIndexed" -> {}},
  GridBoxSpacings->{"Columns" -> {
      Offset[0.27999999999999997`], {
       Offset[0.5599999999999999]}, 
      Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
      Offset[0.2], {
       Offset[0.16]}, 
      Offset[0.2]}, "RowsIndexed" -> {}}},
  CellTags->"S5.1.1"],
 "\nLast Version: 25-Nov-2005"
}], "Abstract",
 CellTags->"b:2.0.1"]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
WindowToolbars->{},
WindowSize->{1014, 678},
WindowMargins->{{118, Automatic}, {Automatic, 89}},
PrintingStartingPageNumber->46,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{612, 792},
"PostScriptOutputFile":>FrontEnd`FileName[{"export", "home", "brunojd"}, 
  "t.ps", CharacterEncoding -> "WindowsANSI"]},
ShowSelection->True,
TaggingRules:>{
 "PaginationCache" -> {{2005, 8, 9, 3, 36, 21.330055`8.081566958720561}, {46, 
    46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 46, 47, 47, 47, 47, 47, 47, 
    47, 47, 47, 47, 47, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 48, 
    49, 49, 49, 49, 49, 49, 49, 49, 49, 50, 50, 50, 50, 50, 50, 50, 50, 50, 
    50, 50, 50, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 51, 52}, 
    Automatic}},
CellLabelAutoDelete->True,
Magnification->1,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit) (November 6, 2010)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "c:1"->{
  Cell[545, 20, 60, 1, 50, "Title",
   CellTags->"c:1"]},
 "c:2"->{
  Cell[1266, 46, 212, 5, 51, "Section",
   CellTags->"c:2"]},
 "c:3"->{
  Cell[1503, 55, 208, 4, 57, "Subsection",
   CellTags->{"c:3", "b:2.0.0"}]},
 "b:2.0.0"->{
  Cell[1503, 55, 208, 4, 57, "Subsection",
   CellTags->{"c:3", "b:2.0.0"}],
  Cell[1714, 61, 1005, 29, 35, "Abstract",
   CellTags->"b:2.0.0"],
  Cell[2722, 92, 283, 6, 49, "Text",
   CellTags->"b:2.0.0"],
  Cell[3008, 100, 133, 3, 46, "Input",
   CellTags->"b:2.0.0"],
  Cell[3144, 105, 112, 3, 46, "Input",
   CellTags->"b:2.0.0"],
  Cell[3259, 110, 311, 9, 60, "Input",
   CellTags->"b:2.0.0"],
  Cell[3573, 121, 219, 6, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[3795, 129, 2996, 84, 61, "DefinitionBox",
   CellTags->{"S5.1.1", "b:2.0.0"}],
  Cell[6794, 215, 461, 17, 51, "Text",
   CellTags->"b:2.0.0"],
  Cell[7258, 234, 451, 14, 49, "Text",
   CellTags->"b:2.0.0"],
  Cell[7712, 250, 1203, 46, 76, "Text",
   CellTags->"b:2.0.0"],
  Cell[8918, 298, 458, 15, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[9379, 315, 224, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[9606, 322, 2072, 55, 90, "Input",
   CellTags->"b:2.0.0"],
  Cell[11681, 379, 2026, 55, 75, "Input",
   CellTags->"b:2.0.0"],
  Cell[13710, 436, 649, 13, 118, "Text",
   CellTags->"b:2.0.0"],
  Cell[14362, 451, 186, 5, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[14551, 458, 278, 9, 26, "Text",
   CellTags->"b:2.0.0"],
  Cell[14832, 469, 102, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[14937, 473, 84, 2, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[15046, 479, 188, 7, 33, "Subsubsection",
   CellTags->{"c:4", "b:2.0.0"}],
  Cell[15237, 488, 568, 17, 105, "Input",
   CellTags->"b:2.0.0"],
  Cell[15808, 507, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[15970, 514, 496, 15, 44, "Input",
   CellTags->"b:2.0.0"],
  Cell[16469, 531, 140, 4, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[16612, 537, 823, 24, 75, "Input",
   CellTags->"b:2.0.0"],
  Cell[17438, 563, 180, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[17655, 573, 110, 2, 33, "Subsubsection",
   CellTags->{"c:5", "b:2.0.0"}],
  Cell[17768, 577, 177, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[17948, 584, 775, 24, 131, "Input",
   CellTags->"b:2.0.0"],
  Cell[18726, 610, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[18888, 617, 1714, 49, 156, "Input",
   CellTags->"b:2.0.0"],
  Cell[20605, 668, 114, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[20722, 672, 936, 27, 111, "Input",
   CellTags->"b:2.0.0"],
  Cell[21661, 701, 551, 11, 118, "Text",
   CellTags->"b:2.0.0"],
  Cell[22215, 714, 258, 7, 60, "Input",
   CellTags->"b:2.0.0"],
  Cell[22510, 726, 108, 2, 33, "Subsubsection",
   CellTags->{"c:6", "b:2.0.0"}],
  Cell[22621, 730, 607, 18, 105, "Input",
   CellTags->"b:2.0.0"],
  Cell[23231, 750, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[23393, 757, 1714, 49, 156, "Input",
   CellTags->"b:2.0.0"],
  Cell[25110, 808, 114, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[25227, 812, 1035, 30, 111, "Input",
   CellTags->"b:2.0.0"],
  Cell[26299, 847, 110, 2, 33, "Subsubsection",
   CellTags->{"c:7", "b:2.0.0"}],
  Cell[26412, 851, 680, 21, 105, "Input",
   CellTags->"b:2.0.0"],
  Cell[27095, 874, 159, 5, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[27257, 881, 1714, 49, 156, "Input",
   CellTags->"b:2.0.0"],
  Cell[28974, 932, 114, 2, 22, "Text",
   CellTags->"b:2.0.0"],
  Cell[29091, 936, 936, 27, 111, "Input",
   CellTags->"b:2.0.0"],
  Cell[30030, 965, 141, 4, 22, "Text",
   CellTags->"b:2.0.0"]},
 "S5.1.1"->{
  Cell[3795, 129, 2996, 84, 61, "DefinitionBox",
   CellTags->{"S5.1.1", "b:2.0.0"}]},
 "c:4"->{
  Cell[15046, 479, 188, 7, 33, "Subsubsection",
   CellTags->{"c:4", "b:2.0.0"}]},
 "c:5"->{
  Cell[17655, 573, 110, 2, 33, "Subsubsection",
   CellTags->{"c:5", "b:2.0.0"}]},
 "c:6"->{
  Cell[22510, 726, 108, 2, 33, "Subsubsection",
   CellTags->{"c:6", "b:2.0.0"}]},
 "c:7"->{
  Cell[26299, 847, 110, 2, 33, "Subsubsection",
   CellTags->{"c:7", "b:2.0.0"}]},
 "b:2.0.1"->{
  Cell[30174, 971, 52, 1, 44, "Input",
   CellTags->"b:2.0.1"],
  Cell[30229, 974, 1005, 29, 35, "Abstract",
   CellTags->"b:2.0.1"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"c:1", 32361, 1036},
 {"c:2", 32429, 1039},
 {"c:3", 32501, 1042},
 {"b:2.0.0", 32593, 1045},
 {"S5.1.1", 35901, 1144},
 {"c:4", 35998, 1147},
 {"c:5", 36091, 1150},
 {"c:6", 36184, 1153},
 {"c:7", 36277, 1156},
 {"b:2.0.1", 36374, 1159}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 60, 1, 50, "Title",
 CellTags->"c:1"],
Cell[608, 23, 192, 5, 55, "Subtitle"],
Cell[803, 30, 287, 8, 20, "Abstract"],
Cell[1093, 40, 148, 2, 22, "Text"],
Cell[CellGroupData[{
Cell[1266, 46, 212, 5, 51, "Section",
 CellTags->"c:2"],
Cell[CellGroupData[{
Cell[1503, 55, 208, 4, 57, "Subsection",
 CellTags->{"c:3", "b:2.0.0"}],
Cell[1714, 61, 1005, 29, 35, "Abstract",
 CellTags->"b:2.0.0"],
Cell[2722, 92, 283, 6, 49, "Text",
 CellTags->"b:2.0.0"],
Cell[3008, 100, 133, 3, 46, "Input",
 CellTags->"b:2.0.0"],
Cell[3144, 105, 112, 3, 46, "Input",
 CellTags->"b:2.0.0"],
Cell[3259, 110, 311, 9, 60, "Input",
 CellTags->"b:2.0.0"],
Cell[3573, 121, 219, 6, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[3795, 129, 2996, 84, 61, "DefinitionBox",
 CellTags->{"S5.1.1", "b:2.0.0"}],
Cell[6794, 215, 461, 17, 51, "Text",
 CellTags->"b:2.0.0"],
Cell[7258, 234, 451, 14, 49, "Text",
 CellTags->"b:2.0.0"],
Cell[7712, 250, 1203, 46, 76, "Text",
 CellTags->"b:2.0.0"],
Cell[8918, 298, 458, 15, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[9379, 315, 224, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[9606, 322, 2072, 55, 90, "Input",
 CellTags->"b:2.0.0"],
Cell[11681, 379, 2026, 55, 75, "Input",
 CellTags->"b:2.0.0"],
Cell[13710, 436, 649, 13, 118, "Text",
 CellTags->"b:2.0.0"],
Cell[14362, 451, 186, 5, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[14551, 458, 278, 9, 26, "Text",
 CellTags->"b:2.0.0"],
Cell[14832, 469, 102, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[14937, 473, 84, 2, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[CellGroupData[{
Cell[15046, 479, 188, 7, 33, "Subsubsection",
 CellTags->{"c:4", "b:2.0.0"}],
Cell[15237, 488, 568, 17, 105, "Input",
 CellTags->"b:2.0.0"],
Cell[15808, 507, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[15970, 514, 496, 15, 44, "Input",
 CellTags->"b:2.0.0"],
Cell[16469, 531, 140, 4, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[16612, 537, 823, 24, 75, "Input",
 CellTags->"b:2.0.0"],
Cell[17438, 563, 180, 5, 22, "Text",
 CellTags->"b:2.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17655, 573, 110, 2, 33, "Subsubsection",
 CellTags->{"c:5", "b:2.0.0"}],
Cell[17768, 577, 177, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[17948, 584, 775, 24, 131, "Input",
 CellTags->"b:2.0.0"],
Cell[18726, 610, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[18888, 617, 1714, 49, 156, "Input",
 CellTags->"b:2.0.0"],
Cell[20605, 668, 114, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[20722, 672, 936, 27, 111, "Input",
 CellTags->"b:2.0.0"],
Cell[21661, 701, 551, 11, 118, "Text",
 CellTags->"b:2.0.0"],
Cell[22215, 714, 258, 7, 60, "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22510, 726, 108, 2, 33, "Subsubsection",
 CellTags->{"c:6", "b:2.0.0"}],
Cell[22621, 730, 607, 18, 105, "Input",
 CellTags->"b:2.0.0"],
Cell[23231, 750, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[23393, 757, 1714, 49, 156, "Input",
 CellTags->"b:2.0.0"],
Cell[25110, 808, 114, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[25227, 812, 1035, 30, 111, "Input",
 CellTags->"b:2.0.0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26299, 847, 110, 2, 33, "Subsubsection",
 CellTags->{"c:7", "b:2.0.0"}],
Cell[26412, 851, 680, 21, 105, "Input",
 CellTags->"b:2.0.0"],
Cell[27095, 874, 159, 5, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[27257, 881, 1714, 49, 156, "Input",
 CellTags->"b:2.0.0"],
Cell[28974, 932, 114, 2, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[29091, 936, 936, 27, 111, "Input",
 CellTags->"b:2.0.0"],
Cell[30030, 965, 141, 4, 22, "Text",
 CellTags->"b:2.0.0"],
Cell[30174, 971, 52, 1, 44, "Input",
 CellTags->"b:2.0.1"],
Cell[30229, 974, 1005, 29, 35, "Abstract",
 CellTags->"b:2.0.1"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
